@@ -309,7 +309,7 @@ mGNtanh <- function(bstart, sigma2, resstart,
           convflag <- FALSE;
           break;  ## quit if Hessian is not positive definite
         }
-        bdiff <- c(solve(hess2, tol=.Machine$double.eps, LINPACK=TRUE) %*% gradient) ;  ## one Newton step
+        bdiff <- c(solve(hess2, tol=.Machine$double.eps) %*% gradient) ;  ## one Newton step
         ## print(bdiff);
         for (lambda in c(10:6)/10) {
           blambda <- bvec + lambda * bdiff;
@@ -357,7 +357,7 @@ mGNtanh <- function(bstart, sigma2, resstart,
         formation <- NA;
       }
       else {
-        formation <- solve(information, tol=.Machine$double.eps, LINPACK=TRUE);
+        formation <- solve(information, tol=.Machine$double.eps);
       }
       return(
              list(coefficients=bvec, tvec=tvec, formation=formation, score=score,
@@ -404,7 +404,7 @@ mGNtanh <- function(bstart, sigma2, resstart,
     }
     else {
       print(paste("mGNtanh: hessian determinant:",
-        det(solve(obsformation, tol=.Machine$double.eps, LINPACK=TRUE))));
+        det(solve(obsformation, tol=.Machine$double.eps))));
     }
     if (any(is.na(opg))) {
       print(paste("mGNtanh: OPG determinant:", NA));
